<!DOCTYPE html>
<html lang="en">
    <body>
        <h2>HTTP Services</h2>
        {% for service in service_groups.get('http', []) %}
        <a href="/{{ service.name }}">{{ service.name }}</a><br/>
        {% endfor %}
        <br/>
        <h2>TCP/UDP Services</h2>
        {% for port, service in service_groups.get('stream', {}).items() %}
        {{ service.name }} forwarded on port {{ port }}{% if 'udp' in service.tags %}/udp{% endif %}<br/>
        {% endfor %}
    </body>
</html>
